**************************************************************************
Python Packaging and Deploying Learning Test Module
**************************************************************************

Thank you for taking a look at EDRN.Jsontest module. This tool performs an json extraction from the following url http://jsonplaceholder.typicode.com/posts/1 and prints out the value associated with "title" attribute.

This is version 0.1 of the test module.

This software was developed by and is copyrighted 2010-2014 by the California
Institute of Technology.  ALL RIGHTS RESERVED.  U.S.  Government sponsorship
acknowledged.

Installation
============

See INSTALL.rst for instructions.

